package
Version:
v0.0.0-...-5ece9d6
Opens a new window with list of versions in this module.
Published: Feb 3, 2024
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func ExecuteCommand(name string)
Execute the registered command
func RegisterCommand(name string, fn func(), description string)
Register command to be used in cli
type Command struct {
Fn func()
Description string
}
Command represents a CLI command with a description.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.